# PyEarthTools Training

This is the training sub-package which forms a part of the [PyEarthTools package](https://github.com/ACCESS-Community-Hub/PyEarthTools).

Documentation for this package is maintained at the [documentation site](https://pyearthtools.readthedocs.io/en/latest/).
